@@ -1,4 +1,4 @@
-/*	$Id: Class1.h,v 1.39 2006/03/17 16:47:08 lhoward Exp $ */
+/*	$Id: Class1.h,v 1.40 2006/07/04 20:45:33 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -176,8 +176,7 @@ protected:
     bool	sendFrame(u_char fcf, const fxStr&, bool lastFrame = true);
     bool	sendFrame(u_char fcf, const u_char* code, const fxStr&, bool lastFrame = true);
     bool	sendRawFrame(HDLCFrame& frame);
-    bool	sendClass1Data(const u_char* data, u_int cc,
-		    const u_char* bitrev, bool eod);
+    bool	sendClass1Data(const u_char* data, u_int cc, const u_char* bitrev, bool eod, long ms);
     bool	sendClass1ECMData(const u_char* data, u_int cc,
 		     const u_char* bitrev, bool eod, u_int ppmcmd, fxStr& emsg);
     bool	recvFrame(HDLCFrame& frame, u_char dir, long ms = 10*1000, bool readPending = false);
