@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h,v 1.21 2006/03/17 16:47:08 lhoward Exp $ */
+/*	$Id: ClassModem.h,v 1.22 2006/07/05 15:54:23 aidan Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -265,7 +265,7 @@ public:
     bool	putModemData(void* data, int n);
     bool	putModemDLEData(const u_char* data, u_int,
 		    const u_char* brev, long ms);
-    bool	putModemLine(const char* cp);
+    bool	putModemLine(const char* cp, long ms = 0);
     int		getModemBit(long ms = 0);
     int		getModemChar(long ms = 0);
     int		getModemDataChar();
