@@ -1,4 +1,4 @@
-/*	$Id: DestInfo.h,v 1.3 2004/04/19 18:44:51 lhoward Exp $ */
+/*	$Id: DestInfo.h,v 1.4 2005/07/13 17:56:22 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -51,6 +51,7 @@ class DestInfo : public QLink {
 private:
     u_short		activeCount;	// count of active jobs to destination
     u_short		blockedCount;	// count of blocked jobs
+    u_short		callCount;	// count of active calls to destination
     FaxMachineInfo	info;		// remote machine capabilities and such
     Job*		running;	// jobs to dest being processed
 public:
@@ -61,6 +62,9 @@ public:
     u_int getActive() const;		// return count of active jobs
     u_int getCount() const;		// return count of active+blocked jobs
     bool isEmpty() const;		// true if any jobs referenced
+    u_int getCalls() const;		// return count of active calls
+    void call();			// initiate call to destination
+    void hangup();			// terminate call to destination
 
     bool isActive(Job&) const;	// true if job is considered active
     bool supportsBatching();		// if remote supports batch protocol
@@ -78,6 +82,9 @@ inline u_int DestInfo::getActive() const	{ return activeCount; }
 inline u_int DestInfo::getCount() const
     { return activeCount + blockedCount; }
 inline bool DestInfo::isEmpty() const		{ return getCount() == 0; }
+inline u_int DestInfo::getCalls() const		{ return callCount; }
+inline void DestInfo::call()			{ callCount++; }
+inline void DestInfo::hangup()			{ callCount--; }
 
 fxDECLARE_StrKeyDictionary(DestInfoDict, DestInfo)
 #endif /* _DestInfo_ */
