@@ -1,4 +1,4 @@
-/*	$Id: FaxRequest.h,v 1.10 2004/11/23 18:51:46 lhoward Exp $ */
+/*	$Id: FaxRequest.h,v 1.12 2005/05/09 14:57:42 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -144,6 +144,8 @@ public:
     fxStr	external;	// displayable phone number for fax machine
     fxStr	notice;		// message to send for notification
     fxStr	modem;		// outgoing modem to use
+    fxStr	faxnumber;	// Sender's number to advertise to phone company
+    fxStr	tsi;		// TSI to use instead of LocalIdentifier
     fxStr	pagehandling;	// page analysis information
     fxStr	receiver;	// receiver's identity for cover page generation
     fxStr	company;	// receiver's company for cover page generation
@@ -161,6 +163,8 @@ public:
     fxStr	jobtype;	// job type for selecting send command
     fxStr	tagline;	// tag line format
     fxStr	doneop;		// operation to do when job completes
+    fxStr	csi;		// CSI string from receiving equipment (ASCII representation)
+    fxStr	nsf;		// NSF string from receiving equipment (ASCII representation)
     pid_t	writeQFilePid;	// pid of last writeQFile operation
     FaxItemArray items;	// set of requests
 
