@@ -1,4 +1,4 @@
-/*	$Id: FaxServer.h,v 1.17 2005/05/06 17:21:19 lhoward Exp $ */
+/*	$Id: FaxServer.h,v 1.18 2006/03/17 16:47:09 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -85,8 +85,8 @@ private:
 protected:
     FaxServer(const fxStr& deviceName, const fxStr& devID);
 
-    bool	setupModem();
-    ClassModem*	deduceModem();
+    bool	setupModem(bool isSend = true);
+    ClassModem*	deduceModem(bool isSend = true);
     void	discardModem(bool dropDTR);
     fxStr	getModemCapabilities() const;
 
