@@ -1,4 +1,4 @@
-/*	$Id: Modem.h,v 1.8 2005/09/27 18:38:26 lhoward Exp $ */
+/*	$Id: Modem.h,v 1.10 2006/04/28 17:24:05 aidan Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -107,7 +107,8 @@ public:
 
     static Modem& getModemByID(const fxStr& id);
     static Modem* modemExists(const fxStr& id);
-    static Modem* findModem(const Job& job, const DestControlInfo& dci);
+    static Modem* findModem(const Job& job);
+    bool isInGroup(const fxStr& mgroup);
 
     bool assign(Job&);		// assign modem
     void release();			// release modem
