@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.42 2006/03/17 16:47:09 lhoward Exp $ */
+/*	$Id: ModemConfig.h,v 1.44 2006/07/21 08:46:17 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -151,7 +151,6 @@ public:
     fxStr	class1SwitchingCmd;	// after recv HDLC and before sending
     fxStr	class1MsgRecvHackCmd;	// cmd to avoid +FCERROR before image
     u_int	class1TCFRecvTimeout;	// timeout receiving TCF
-    u_int	class1SendMsgDelay;	// delay (ms) after training
     u_int	class1TrainingRecovery;	// delay (ms) after failed training
     u_int	class1RecvAbortOK;	// if non-zero, OK sent after recv abort
     u_int	class1RMPersistence;	// how many times to persist through +FCERROR
@@ -227,6 +226,7 @@ public:
     fxStr	tagLineFmt;		// format string for tag lines
     fxStr	tagLineFontFile;	// font file for imaging tag lines
     u_int	recvDataFormat;		// received facsimile data format
+    bool	useJobTagLine;		// Use Job tagline or use conf taglineformat
 
     RTNHandling rtnHandling;            // RTN signal handling method
     JBIGSupport	class1JBIGSupport;	// monochrome JBIG support
