@@ -1,4 +1,4 @@
-/*	$Id: ModemServer.h,v 1.12 2005/04/19 17:46:35 lhoward Exp $ */
+/*	$Id: ModemServer.h,v 1.13 2006/03/17 16:47:10 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -127,10 +127,10 @@ protected:
     ModemServer(const fxStr& deviceName, const fxStr& devID);
 
 // modem driver setup+teardown interfaces
-    virtual bool setupModem();
+    virtual bool setupModem(bool isSend = true);
     virtual bool readyModem();
     virtual void discardModem(bool dropDTR);
-    virtual ClassModem* deduceModem();
+    virtual ClassModem* deduceModem(bool isSend = true);
 // low-level modem interfaces
     int		getModemFd();				// XXX
     BaudRate	getModemRate() const;
