@@ -1,4 +1,4 @@
-/*	$Id: faxGettyApp.h,v 1.13 2005/02/14 13:56:31 lhoward Exp $ */
+/*	$Id: faxGettyApp.h,v 1.15 2006/03/17 16:47:10 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -67,10 +67,6 @@ private:
 
     u_short	ringsBeforeAnswer;	// # rings to wait
     u_short	ringsHeard;		// # rings received
-    fxStr	qualifyCID;		// if set, no answer w/o acceptable cid
-    time_t	lastCIDModTime;		// last mod time of CID patterns file
-    REArray*	cidPats;		// recv cid patterns
-    fxBoolArray* acceptCID;		// accept/reject matched cid
     CallID	received_callid;	// non-null received CNID
     fxStr	gettyArgs;		// getty arguments
     fxStr	vgettyArgs;		// voice getty arguments
@@ -87,6 +83,7 @@ private:
     fxStr	dynamicConfig;		// command to dynamically alter configuration
     u_int	modemPriority;		// modem priority passed to faxq
     bool	logCalls;		// Log all calls for FaxAcctInfo
+    bool	rejectCall;
 
     static faxGettyApp* _instance;
 
@@ -106,10 +103,9 @@ private:
     bool	canLockModem();
     bool	lockModem();
     void	unlockModem();
-    bool	setupModem();
+    bool	setupModem(bool isSend);
     void	discardModem(bool dropDTR);
 // inbound call handling
-    bool	isCIDOk(const fxStr& cid);
     bool	processCall(CallType ctype, fxStr& emsg, const CallID& callid);
     CallType	runGetty(const char* what,
 		    Getty* (*newgetty)(const fxStr&, const fxStr&),
