@@ -1,4 +1,4 @@
-/*	$Id: faxQueueApp.h,v 1.25 2006/04/28 17:24:06 aidan Exp $ */
+/*	$Id: faxQueueApp.h,v 1.26 2006/07/03 21:08:32 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -216,8 +216,10 @@ private:
     bool	suspendJob(const fxStr& jobid, bool abortActive);
     void	rejectSubmission(Job&, FaxRequest&, const fxStr& reason);
     bool	areBatchable(Job& job, Job& nextjob, FaxRequest& nextreq);
+    void	batchJob(Job* prevjob, Job* nextjob, FaxRequest* nextreq);
 
     void	setReadyToRun(Job& job, bool wait);
+    void	setReady(Job& job);
     void	setSleep(Job& job, time_t tts);
     void	setDead(Job& job);
     void	setActive(Job& job);
@@ -232,7 +234,7 @@ private:
     void	runJob(Job& job);
 
     void	removeDestInfoJob(Job& job);
-    void        unblockDestJobs(Job& job, DestInfo& di);
+    void        unblockDestJobs(DestInfo& di);
 
     bool	scheduling();
     void	runScheduler();
