@@ -1,4 +1,4 @@
-/*	$Id: pageSendApp.h,v 1.6 2005/09/27 18:47:41 lhoward Exp $ */
+/*	$Id: pageSendApp.h,v 1.8 2006/03/23 20:17:33 lhoward Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -104,7 +104,7 @@ private:
     bool	canLockModem();
     bool	lockModem();
     void	unlockModem();
-    bool	setupModem();
+    bool	setupModem(bool isSend);
 // notification interfaces used by ModemServer
     void	notifyModemReady();
     void	notifyModemWedged();
@@ -123,7 +123,7 @@ public:
     void	open();
     void	close();
 
-    FaxSendStatus send(const char* filename);
+    FaxSendStatus send(const char** filename, int num);
 
     bool	isReady() const;
 };
