@@ -1,4 +1,4 @@
-/* $Id: tif_fax3.h,v 1.3 2002/07/23 21:08:43 darren Exp $ */
+/* $Id: tif_fax3.h,v 1.4 2005/11/29 21:23:56 lhoward Exp $ */
 
 /*
  * Copyright (c) 1990-1997 Sam Leffler
@@ -255,21 +255,27 @@ static const char* StateNames[] = {
  * 11 consecutive zero bits.  This means that if EOLcnt
  * is non-zero then we still need to scan for the final flag
  * bit that is part of the EOL code.
+ *
+ * In order to prevent getting forever stuck in these loops
+ * (perhaps by a hung modem or hung sender) we raiseRTC if
+ * it appears to be the case.
  */
 #define	SYNC_EOL(eoflab) do {						\
     if (EOLcnt == 0) {							\
-	for (;;) {							\
+	for (u_long i = 0;; i++) {					\
 	    NeedBits16(11,eoflab);					\
 	    if (GetBits(11) == 0)					\
 		break;							\
 	    ClrBits(1);							\
+	    if (i > 150000) raiseRTC();					\
 	}								\
     }									\
-    for (;;) {								\
+    for (u_long i = 0;; i++) {						\
 	NeedBits8(8,eoflab);						\
 	if (GetBits(8))							\
 	    break;							\
 	ClrBits(8);							\
+	if (i > 150000) raiseRTC();					\
     }									\
     while (GetBits(1) == 0)						\
 	ClrBits(1);							\
