@@ -1,4 +1,4 @@
-/*	$Id: TypeRules.h,v 1.6 2003/10/04 18:19:27 lhoward Exp $ */
+/*	$Id: TypeRules.h,v 1.7 2006/01/30 21:40:50 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -70,8 +70,8 @@
  *	  and embedded spaces, but not embedded tabs, are allowed.
  *	  These data are taken literally; no C-style character escapes
  *         are meaningful.
- * result: one of "PS", "TIFF, or "error" (case insensitive).  The first
- *	  two results specifiy whether the rule generates a PostScript
+ * result: one of "PS", "TIFF", "PDF", or "error" (case insensitive).  The
+ *	  first two results specifiy whether the rule generates a PostScript
  *	  file or a bilevel TIFF image.  The "error" result indicates a
  *	  file is unsuitable for transmission and if supplied as an
  *	  argument to sendfax, the command should be aborted.
@@ -129,6 +129,7 @@ public:
     enum {
 	TIFF,		// bilevel Group 3-encoded TIFF
 	POSTSCRIPT,	// PostScript
+	PDF,		// Portable Document Format
 	ERROR		// recognized erronious format
     };
 private:
