@@ -1,4 +1,4 @@
-/*	$Id: class2.h,v 1.8 2004/03/29 18:57:52 lhoward Exp $ */
+/*	$Id: class2.h,v 1.11 2005/09/27 19:29:11 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -79,12 +79,10 @@ const u_short BR_31200	= 12;		// 31200 bit/s
 const u_short BR_33600	= 13;		// 33600 bit/s
 const u_short BR_ALL	= BIT(BR_33600+1)-1;
 
-const u_short WD_1728	= 0;		// 1728 pixels in 215 mm
-const u_short WD_2048	= 1;		// 2048 pixels in 255 mm
-const u_short WD_2432	= 2;		// 2432 pixels in 303 mm
-const u_short WD_1216	= 3;		// 1216 pixels in 151 mm
-const u_short WD_864	= 4;		// 864 pixels in 107 mm
-const u_short WD_ALL	= BIT(WD_864+1)-1;
+const u_short WD_A4	= 0;		// 1728 pixels in 215 mm
+const u_short WD_B4	= 1;		// 2048 pixels in 255 mm
+const u_short WD_A3	= 2;		// 2432 pixels in 303 mm
+const u_short WD_ALL	= BIT(WD_A3+1)-1;
 
 const u_short LN_A4		= 0;		// A4, 297 mm
 const u_short LN_B4		= 1;		// B4, 364 mm
@@ -97,6 +95,9 @@ const u_short DF_1DMH	= 0;		// 1-D Modified Huffman
 const u_short DF_2DMR	= 1;		// 2-D Modified Read
 const u_short DF_2DMRUNCOMP	= 2;		// 2-D Uncompressed Mode
 const u_short DF_2DMMR	= 3;		// 2-D Modified Modified Read
+const u_short DF_JBIG	= 4;		// Single-progression sequential coding (Rec. T.85)
+const u_short DF_JPEG_GREY	= 5;	// Greyscale JPEG (T.4 Annex E and T.81)
+const u_short DF_JPEG_COLOR	= 6;	// Full-color JPEG (T.4 Annex E and T.81)
 const u_short DF_ALL	= BIT(DF_2DMMR+1)-1;
 
 /*
