@@ -1,4 +1,4 @@
-/*	$Id: faxadduser.c,v 1.7 2006/01/09 17:18:31 aidan Exp $ */
+/*	$Id: faxadduser.c,v 1.8 2006/08/12 20:51:30 pfournier Exp $ */
 /*
  * Copyright (c) 1999 Robert Colquhoun
  *
@@ -49,7 +49,7 @@ extern char* optarg;
 const char passwd_salts[] = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./";
 
 const char* usage = "faxadduser [-a admin-password] [-f hosts-file] \
-[ -p password] [-u uid] username";
+[-h host-name] [-p password] [-u uid] username";
 
 int
 main(int argc, char** argv)
