@@ -1,4 +1,4 @@
-/*	$Id: faxstate.c,v 1.5 2003/02/08 22:22:18 darren Exp $ */
+/*	$Id: faxstate.c,v 1.6 2006/07/21 18:17:15 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -121,7 +121,7 @@ main(int argc, char** argv)
     } else {
         fatal("Argument is too large: %s", argv[optind]);
     }
-    for (cp = devid; cp = strchr(cp, '/'); *cp++ = '_')
+    for (cp = devid; (cp = strchr(cp, '/')); *cp++ = '_')
 	;
     if (chdir(spooldir) < 0)
 	fatal("%s: chdir: %s", spooldir, strerror(errno));
